@@ -110,7 +110,7 @@ class Agent(threading.Thread):
             try:
                 trans.run()
                 trans.br.clean_session()
-            except Exception, e:  # test runner catches all script exceptions here
+            except Exception as e:  # test runner catches all script exceptions here
                 error = str(e).replace(',', '')
 
             finish = self.default_timer()
