@@ -22,15 +22,13 @@ def resp_graph_raw(nested_resp_list, image_name, dir='./'):
 # response time graph for bucketed data
 def resp_graph(avg_resptime_points_dict, percentile_80_resptime_points_dict,
                percentile_90_resptime_points_dict, image_name, dir='./'):
-    fig = pygal.Line(human_readable=True, x_title='Elapsed Time In Test (secs)', y_title='Response Time (secs)')
+    fig = pygal.XY(human_readable=True, x_title='Elapsed Time In Test (secs)', y_title='Response Time (secs)')
     x_seq = sorted(avg_resptime_points_dict.keys())
-    fig.y_scale = 0.5
-    fig.add('AVG', [avg_resptime_points_dict[x] for x in x_seq])
+    fig.add('AVG', [(0, None)] + [(x, avg_resptime_points_dict[x]) for x in x_seq])
     x_seq = sorted(percentile_90_resptime_points_dict.keys())
-    fig.add('90pct', [percentile_90_resptime_points_dict[x] for x in x_seq])
+    fig.add('90pct', [(0, None)] + [(x, percentile_90_resptime_points_dict[x]) for x in x_seq])
     x_seq = sorted(percentile_80_resptime_points_dict.keys())
-    fig.add('80pct', [percentile_80_resptime_points_dict[x] for x in x_seq])
-    fig.x_labels = map(str, range(1, len(x_seq) + 1))
+    fig.add('80pct', [(0, None)] + [(x, percentile_80_resptime_points_dict[x]) for x in x_seq])
     fig.render_to_file(filename=dir + image_name)
 
 
