@@ -24,8 +24,8 @@ class ProgressBar(object):
         self.prog_bar = '[' + self.fill_char * num_hashes + ' ' * (all_full - num_hashes) + ']'
         pct_place = (len(self.prog_bar) / 2) - len(str(percent_done))
         pct_string = '%i%%' % percent_done
-        self.prog_bar = self.prog_bar[0:pct_place] + \
-            (pct_string + self.prog_bar[pct_place + len(pct_string):])
+        self.prog_bar = self.prog_bar[0:int(pct_place)] + \
+            (pct_string + self.prog_bar[int(pct_place) + len(pct_string):])
 
     def update_time(self, elapsed_secs):
         self.__update_amount((elapsed_secs / float(self.duration)) * 100.0)
